"""
    Created on 2012-02-12
    @author: jldupont
"""

def dnorm(d):
    """
    Normalize dictionary
    
    >>> dnorm({"SoMeKeY":"  spaces  "})
    {'somekey': 'spaces'}
    """
    r={}
    for e in d:
        try:    r[e.lower()]=d[e].strip()
        except: r[e.lower()]=d[e]
    return r



"""
    Created on 2012-01-19
    @author: jldupont
"""
import os

try:
    import zmq
except:
    raise Exception("* package 'pyzmq' is required - get it from Pypi\n")

try:
    import argparse
except:
    raise Exception("* package 'argparse' is necessary - get it from Pypi\n")

